@@ -1,10 +1,6 @@
 package Bio::DB::EUtilities;
-BEGIN {
-  $Bio::DB::EUtilities::AUTHORITY = 'cpan:BIOPERLML';
-}
-{
-  $Bio::DB::EUtilities::VERSION = '1.73';
-}
+our $AUTHORITY = 'cpan:BIOPERLML';
+$Bio::DB::EUtilities::VERSION = '1.74';
 use utf8;
 use strict;
 use warnings;
@@ -400,7 +396,7 @@ Bio::DB::EUtilities - Webagent which interacts with and retrieves data from NCBI
 
 =head1 VERSION
 
-version 1.73
+version 1.74
 
 =head1 SYNOPSIS
 
@@ -1246,7 +1242,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  https://redmine.open-bio.org/projects/bioperl/
+  https://github.com/bioperl/%%7Bdist%7D
 
 =head1 AUTHOR
 
