@@ -1,10 +1,6 @@
 package Bio::Tools::EUtilities;
-BEGIN {
-  $Bio::Tools::EUtilities::AUTHORITY = 'cpan:BIOPERLML';
-}
-{
-  $Bio::Tools::EUtilities::VERSION = '1.73';
-}
+our $AUTHORITY = 'cpan:BIOPERLML';
+$Bio::Tools::EUtilities::VERSION = '1.74';
 use utf8;
 use strict;
 use warnings;
@@ -789,7 +785,7 @@ Bio::Tools::EUtilities - NCBI eutil XML parsers.
 
 =head1 VERSION
 
-version 1.73
+version 1.74
 
 =head1 SYNOPSIS
 
@@ -1533,7 +1529,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  https://redmine.open-bio.org/projects/bioperl/
+  https://github.com/bioperl/%%7Bdist%7D
 
 =head1 AUTHOR
 
