@@ -1,10 +1,6 @@
 package Bio::Tools::EUtilities::EUtilParameters;
-BEGIN {
-  $Bio::Tools::EUtilities::EUtilParameters::AUTHORITY = 'cpan:BIOPERLML';
-}
-{
-  $Bio::Tools::EUtilities::EUtilParameters::VERSION = '1.73';
-}
+our $AUTHORITY = 'cpan:BIOPERLML';
+$Bio::Tools::EUtilities::EUtilParameters::VERSION = '1.74';
 use utf8;
 use strict;
 use warnings;
@@ -33,32 +29,32 @@ my %MODE = (
     'epost'     => {
         'mode'     => ['POST','GET'],
         'location' => 'epost.fcgi',
-        'params'   => [qw(db retmode id tool email WebEnv query_key)],
+        'params'   => [qw(db retmode id tool email idtype WebEnv query_key)],
                    },
     'efetch'    => {
         'mode'     => ['GET','POST'],
         'location' => 'efetch.fcgi',
         'params'   => [qw(db retmode id retmax retstart rettype strand seq_start
-                       seq_stop complexity report tool email WebEnv query_key)],
+                       seq_stop complexity report tool email idtype WebEnv query_key)],
                    },
     'esearch'   => {
         'mode'     => ['GET','POST'],
         'location' => 'esearch.fcgi',
         'params'   => [qw(db retmode usehistory term field reldate mindate
-                       maxdate datetype retmax retstart rettype sort tool email
+                       maxdate datetype retmax retstart rettype sort tool email idtype
                        WebEnv query_key)],
                    },
     'esummary'  => {
         'mode'     => ['GET','POST'],
         'location' => 'esummary.fcgi',
-        'params'   => [qw(db retmode id retmax retstart rettype tool email
+        'params'   => [qw(db retmode id retmax retstart rettype tool email idtype
                        version WebEnv query_key)],
                    },
     'elink'     => {
         'mode'     => ['GET','POST'],
         'location' => 'elink.fcgi',
         'params'   => [qw(db retmode id reldate mindate maxdate datetype term
-                    dbfrom holding cmd version tool email linkname WebEnv
+                    dbfrom holding cmd version tool email idtype linkname WebEnv
                     query_key)],
                    },
     'egquery'   => {
@@ -81,7 +77,7 @@ BEGIN {
     @PARAMS = qw(db id email retmode rettype usehistory term field tool
     reldate mindate maxdate datetype retstart retmax sort seq_start seq_stop
     strand complexity report dbfrom cmd holding version linkname WebEnv
-    query_key);
+    query_key idtype);
     for my $method (@PARAMS) {
         eval <<END;
 sub $method {
@@ -364,7 +360,7 @@ sub id_file {
 
 
 {
-    my $HOSTBASE = 'http://eutils.ncbi.nlm.nih.gov/entrez/eutils/';
+    my $HOSTBASE = 'https://eutils.ncbi.nlm.nih.gov/entrez/eutils/';
 
     sub url_base_address {
         my ($self, $address) = @_;
@@ -421,7 +417,7 @@ Bio::Tools::EUtilities::EUtilParameters - Manipulation of NCBI eutil-based param
 
 =head1 VERSION
 
-version 1.73
+version 1.74
 
 =head1 SYNOPSIS
 
@@ -582,7 +578,7 @@ passing, though these should be easily added in the future when necessary.
  Usage   : $string = $pobj->to_string;
  Function: Returns string (URL only in this case)
  Returns : String (URL only for now)
- Args    : [optional] 'all'; build URI::http using all parameters
+ Args    : [optional] 'all'; build URI::https using all parameters
            Default : Builds based on allowed parameters (presence of history data
            or eutil type in %MODE).
  Note    : Changes state of object.  Absolute string
@@ -689,7 +685,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  https://redmine.open-bio.org/projects/bioperl/
+  https://github.com/bioperl/%%7Bdist%7D
 
 =head1 AUTHOR
 
