@@ -1,10 +1,6 @@
 package Bio::Tools::EUtilities::Info::LinkInfo;
-BEGIN {
-  $Bio::Tools::EUtilities::Info::LinkInfo::AUTHORITY = 'cpan:BIOPERLML';
-}
-{
-  $Bio::Tools::EUtilities::Info::LinkInfo::VERSION = '1.73';
-}
+our $AUTHORITY = 'cpan:BIOPERLML';
+$Bio::Tools::EUtilities::Info::LinkInfo::VERSION = '1.74';
 use utf8;
 use strict;
 use warnings;
@@ -124,7 +120,7 @@ Bio::Tools::EUtilities::Info::LinkInfo - Class for storing einfo link data.
 
 =head1 VERSION
 
-version 1.73
+version 1.74
 
 =head1 SYNOPSIS
 
@@ -269,7 +265,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  https://redmine.open-bio.org/projects/bioperl/
+  https://github.com/bioperl/%%7Bdist%7D
 
 =head1 AUTHOR
 
